@@ -3,7 +3,7 @@ from .plotmath import (
     show,
     savefig,
     histogram,
-    plot_polygon,
+    polygon,
     multiplot,
     gca,
     COLORS,
@@ -16,7 +16,7 @@ __all__ = [
     "savefig",
     "show",
     "histogram",
-    "plot_polygon",
+    "polygon",
     "multiplot",
     "gca",
     "COLORS",
